==> dotx-0.0.1.tar.gz: dotx-0.0.1/TODO.md <==
- [x] If ignore strings go into the context, do I have to pass the context into all my deeper-level functions?  I probably do anyway for DEBUG and VERBOSE settings.  (No, I can actually get the current context directly without passing it all the way down.  Wrote `is_debug_mode()` and friends to leverage this.  Too bad I had to test them by hand.)
- [x] Figure out how to test `options.is_debug_mode()` and friends (Click doesn't seem to want to do the right thing here, so tested by hand)
- [x] Collect all plans before executing _any_ plans
- [x] Collect a list of plans, one plan per package to be installed; then report all failures at the end
- [x] Set up logging
- [x] Check for leaf files existing, that should throw an exception: this install can't be done without destroying files
- [x] Usage?  Mark --target as required or else figure out what the default is.  Is it ${HOME}
- [x] How good can I make ignore.py without it taking over the whole project?  Is ignoring single directories good enough for now?  Yes, ignoring single names withing paths is good enough for now.
- [x] Add docstrings everywhere
- [x] Make `execute_plan` the thing that respects "DRYRUN"
- [x] Try picologging.  Nope: for some reason, picologging doesn't work at all.  Fails with an internal error.  Try again when it has matured a little.
- [x] Implement globbing in the ignore code
- [x] Make dry-run for install spit out the commands that could be used to do it, without actually doing it
- [x] Figure out why .config/bat/config doesn't install correctly
- [x] Uninstall (feels like I can't do this with perfect fidelity)
  - [-] Can I delete empty directories I _might_ have created during installation?
- [x] Test `execute_plan` in dry-run mode to see the commands: are they right
- [x] Do the PyPI installation tutorial

- [ ] Rearrange project as per PyPI demo project
  - [ ] Rename project to `dotx`
  - [ ] Rebuild venv
  - [ ] Re-install (editable) in the local venv
- [ ] Switch build back-end to `hatch`
- [ ] Upload to PyPI

- [ ] What else goes in pyproject.toml?
- [ ] How best to _exit_ the program
- [ ] Unit tests that look at deeper functions than just `plan_install`
- [ ] Log everything
- [ ] Add VERBOSE and DEBUG output

- [ ] For testing, is there a better way of creating all these test files and test directories.  I'm fine with how I make the roots
- [ ] Look at Sphinx (do I require MyST if I want to use Markdown?)
- [ ] Think about the ignore system: ignore files, cached regexes, what else can be done?
- [ ] Figure out (maybe) how to make shorter relative paths to deeper install links
-

==> dotx-0.0.4.tar.gz: dotx-0.0.4/TODO.md <==
- [x] If ignore strings go into the context, do I have to pass the context into all my deeper-level functions?  I probably do anyway for DEBUG and VERBOSE settings.  (No, I can actually get the current context directly without passing it all the way down.  Wrote `is_debug_mode()` and friends to leverage this.  Too bad I had to test them by hand.)
- [x] Figure out how to test `options.is_debug_mode()` and friends (Click doesn't seem to want to do the right thing here, so tested by hand)
- [x] Collect all plans before executing _any_ plans
- [x] Collect a list of plans, one plan per package to be installed; then report all failures at the end
- [x] Set up logging
- [x] Check for leaf files existing, that should throw an exception: this install can't be done without destroying files
- [x] Usage?  Mark --target as required or else figure out what the default is.  Is it ${HOME}
- [x] How good can I make ignore.py without it taking over the whole project?  Is ignoring single directories good enough for now?  Yes, ignoring single names withing paths is good enough for now.
- [x] Add docstrings everywhere
- [x] Make `execute_plan` the thing that respects "DRYRUN"
- [x] Try picologging.  Nope: for some reason, picologging doesn't work at all.  Fails with an internal error.  Try again when it has matured a little.
- [x] Implement globbing in the ignore code
- [x] Make dry-run for install spit out the commands that could be used to do it, without actually doing it
- [x] Figure out why .config/bat/config doesn't install correctly
- [x] Uninstall (feels like I can't do this with perfect fidelity)
  - [-] Can I delete empty directories I _might_ have created during installation?
- [x] Test `execute_plan` in dry-run mode to see the commands: are they right
- [x] Do the PyPI installation tutorial
- [x] Rearrange project as per PyPI demo project
  - [x] Rename project to `dotx`
  - [x] Rebuild venv
  - [x] Re-install (editable) in the local venv
- [x] Switch build back-end to `hatch`
- [x] Upload to PyPI

- [ ] What else goes in pyproject.toml?
- [ ] How best to _exit_ the program
- [ ] Unit tests that look at deeper functions than just `plan_install`
- [ ] Log everything
- [ ] Add VERBOSE and DEBUG output

- [ ] For testing, is there a better way of creating all these test files and test directories.  I'm fine with how I make the roots
- [ ] Look at Sphinx (do I require MyST if I want to use Markdown?)
- [ ] Think about the ignore system: ignore files, cached regexes, what else can be done?
- [ ] Figure out (maybe) how to make shorter relative paths to deeper install links
-
